cansig
======

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   cansig.cluster
   cansig.cnvanalysis
   cansig.interface
   cansig.metaanalysis
   cansig.models
   cansig.plotting
   cansig.run
   cansig.types
   cansig.filesys
